** assumes that image and file are stored in same &OUTPATH folder;
ods html close;
title; footnote;
   
ods html(id=ex2) file="&outpath\example2_COMPUTE_BEFORE_AFTER.html";

proc report data=shoes spanrows;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'Ex 2a) COMPUTE BEFORE/AFTER with LINE';
  column region product sales returns Profit inventory PctInv ;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  break after region/summarize;
  rbreak after / summarize;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute before  / style=Header{fontweight=bold fontsize=18pt};
     line "Shoe Zoo: We've got everything from boots to bunny slippers!";
  endcomp;
  compute after  / style=Header{fontweight=bold fontsize=18pt};
     line "Shoe Zoo: We've got everything from boots to bunny slippers!";
  endcomp;
run;

proc report data=shoes spanrows;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'Ex 2b) COMPUTE BEFORE/AFTER with image';
  column region product sales returns Profit inventory PctInv ;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  break after region/summarize;
  rbreak after / summarize;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute before  / style={background=white preimage="&outpath\shoe_zoo.png"};
     line ' ';
  endcomp;
  compute after  / style={background=white preimage="&outpath\shoe_zoo.png"};
     line ' ';
  endcomp;
run;

ods html(id=ex2) close;

   
ods escapechar='^';
ods html(id=ex2c) file="&outpath\example2_COMPUTE_AFTER_MORE_LINES.html";

proc report data=shoes spanrows;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'Ex 2c) COMPUTE BEFORE/AFTER with LINE';
  column region product sales returns Profit inventory PctInv sales=salesmn returns=retmn inventory=invmn;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  define salesmn / mean noprint;
  define retmn / mean noprint;
  define invmn / mean noprint;
  break after region/summarize;
  rbreak after / summarize  style=Header;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute after  / style=Header{just=l fontweight=bold fontsize=14pt};
     region = 'All Regions';
	 cinv = left(put(invmn,dollar10.));
	 csal = left(put(salesmn,dollar10.));
	 cret = left(put(retmn,dollar10.));
	 line "^{style[textdecoration=underline]Averages for These Regions}";
	 line "Inventory: " cinv $varying50.;
	 line "Sales: " csal $varying50.;
	 line "Returns: " cret $varying50.;
  endcomp;
run;

ods html(id=ex2c) close;

title; footnote;
   
ods html(id=ex2d) file="&outpath\example2_COMPUTE_AFTER_PAGE.html";

proc report data=shoes spanrows;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'Ex 2d) COMPUTE BEFORE/AFTER with PAGE option on BREAK';
  column region product sales returns Profit inventory PctInv sales=salesmn returns=retmn inventory=invmn;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  define salesmn / mean noprint;
  define retmn / mean noprint;
  define invmn / mean noprint;
  break after region/summarize page;
  rbreak after / summarize  style=Header;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute after  / style=Header{just=l fontweight=bold fontsize=14pt};
     region = 'All Regions';
	 cinv = left(put(invmn,dollar10.));
	 csal = left(put(salesmn,dollar10.));
	 cret = left(put(retmn,dollar10.));
	 line "^{style[textdecoration=underline]Averages for These Regions}";
	 line "Inventory: " cinv $varying50.;
	 line "Sales: " csal $varying50.;
	 line "Returns: " cret $varying50.;
  endcomp;
run;

ods html(id=ex2d) close;

   
ods escapechar='^';
ods html(id=ex2e) file="&outpath\example2_COMPUTE_AFTER_with_BY.html";

proc report data=shoes spanrows; by region;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'Ex 2e) COMPUTE BEFORE/AFTER with';
  column region product sales returns Profit inventory PctInv sales=salesmn returns=retmn inventory=invmn;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  define salesmn / mean noprint;
  define retmn / mean noprint;
  define invmn / mean noprint;
  break after region/summarize;
  rbreak after / summarize  style=Header;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute after  / style=Header{just=l fontweight=bold fontsize=14pt};
     region = 'All Regions';
	 cinv = left(put(invmn,dollar10.));
	 csal = left(put(salesmn,dollar10.));
	 cret = left(put(retmn,dollar10.));
	 line "^{style[textdecoration=underline]Averages for These Regions}";
	 line "Inventory: " cinv $varying50.;
	 line "Sales: " csal $varying50.;
	 line "Returns: " cret $varying50.;
  endcomp;
run;

ods html(id=ex2e) close;

