** assumes that image and file are stored in same &OUTPATH folder;
ods html close;
title; footnote;
   
ods html(id=ex4) file="&outpath\example4_COMPUTE_Custom_Msg.html";

proc report data=shoes spanrows
     style(summary)=Header;
  title 'Ex 4a) COMPUTE BLOCK ';
  column region product sales returns Profit inventory PctInv ;
  define region / group noprint;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  break after region/summarize;
  rbreak after / summarize;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute before region  / style=Header{just=l fontweight=bold fontsize=12pt};
     topprod = .;
	 thisregion = region;
	 line Region $varying100.;
  endcomp;
  compute sales;
    if _break_ = ' ' then do;
      if sales.sum gt topprod then do;
         topprod = sales.sum;
	     holdprod = Product;
      end;
    end;
  endcomp;
  compute product;
    if upcase(_break_) = 'REGION' then product=catx(' ',region,'Total');
    else if _break_ = '_RBREAK_' then product = 'Grand Total';
  endcomp;
  compute after region  / style=Header{just=l fontweight=bold fontsize=12pt};
     brkline=catx(' ','Top Product for', thisregion, 'is',holdprod,'with sales of',put(topprod,dollar14.));
     line brkline $varying100.;
	 line ' ';
  endcomp;
run;

ods html(id=ex4) close;

 
*** Example 04 More Complex ***;
options center missing=' ';
title;
footnote;
 
proc sort data=sashelp.shoes out=pctshoes;
  where region in ('Pacific' 'Canada')  ;
  by region product;
run;

ods html(id=ex4b) file="&outpath\Example04__pctsum.html" ;
  proc report data=pctshoes nowd spanrows 
    style(summary)=Header;
    title 'Ex 4b) Percent Calculated with PCTSUM Statistic';
    column region product Sales Sales=psal;
    define region / group 'Region' f=$25.
           style(column)=Header;
    define product / group 'Product';
    define Sales / sum 'Sales' f=comma14.;
    define psal / pctsum 'Percent of Report Total' f=percent9.2;
    break after region / summarize;
    rbreak after / summarize;
	compute sales;
	  if upcase(_break_) in ('REGION' '_RBREAK_') then do;
	    call define(_col_,'format','dollar15.');
	  end;
	endcomp;
  run;

ods html(id=ex4b) close;

ods html(id=ex4c) file="&outpath\Example04__grppct.html" ;
 
  proc report data=pctshoes nowd spanrows  
    style(summary)=Header;
    title 'Ex 4c1) Percent PROC REPORT';
    title2 'Calculated with Temporary Variables';
    column region     
           product Sales PctGrp Sales=psal;
    define region / group 'Region' f=$25.
           style(column)=Header;
    define product / group 'Product';
    define Sales / sum 'Sales' f=comma14.;
    define pctgrp / computed 'Percent of Region' f=percent9.2;
    define psal / pctsum 'Percent of Total' f=percent9.2;
 
    break after region / summarize;
    rbreak after / summarize;

    compute before region;
      grptot=Sales.sum;
    endcomp;

    compute PctGrp;
       PctGrp=Sales.sum / grptot;
    endcomp;

	compute sales;
	  if upcase(_break_) in ('REGION' '_RBREAK_') then do;
	    call define(_col_,'format','dollar15.');
	  end;
	endcomp;
    compute after;
      PctGrp = .;
      region = 'Overall Report';
    endcomp;
  run;

  
  proc report data=pctshoes nowd  spanrows
    style(summary)=Header;
    title 'Ex 4c2) Desired Percent of Region and Percent of Total';
    title2 'Note value for Percent of Region';
    column region     
           product Sales PctGrp 
           Sales=psal;
    define region / group 'Region' f=$25.
           style(column)=Header;
    define product / group 'Product';
    define Sales / sum 'Sales' f=comma14.;
    define pctgrp / computed 'Percent of Region' f=percent9.2;
    define psal / pctsum 'Percent of Total' f=percent9.2;
 
    break after region / summarize;
    rbreak after / summarize;

    compute before region;
      grptot=Sales.sum;
    endcomp;

    compute PctGrp;
       PctGrp=Sales.sum / grptot;
    endcomp;

	compute sales;
	  if upcase(_break_) in ('REGION' '_RBREAK_') then do;
	    call define(_col_,'format','dollar15.');
	  end;
	endcomp;
    compute after;
      region = 'Overall Report';
    endcomp;
  run;

ods html(id=ex4c) close;

ods listing close;
ods html(id=ex4d) file="&outpath\Example04__grppct_comment.html" ;
 
  proc report data=pctshoes nowd spanrows 
    style(summary)=Header;
    title 'Ex 4d) Comment on PROC REPORT';
    title2 'Calculated with Temporary Variables';
    column region     
           product Sales PctGrp 
           comment Sales=psal;
    define region / group 'Region' f=$25.
           style(column)=Header;
    define product / group 'Product';
    define Sales / sum 'Sales' f=comma14.;
    define pctgrp / computed 'Percent of Region' f=percent9.2;
    define psal / pctsum 'Percent of Total' f=percent9.2;
    define comment / computed 'Comment';
 
    break after region / summarize;
    rbreak after / summarize;

    compute before region;
      grptot=Sales.sum;
    endcomp;

    compute PctGrp;
       PctGrp=Sales.sum / grptot;
    endcomp;

	compute sales;
	  if upcase(_break_) in ('REGION' '_RBREAK_') then do;
	    call define(_col_,'format','dollar15.');
	  end;
	endcomp;
    compute after;
      region = 'Overall Report';
    endcomp;

    compute comment / character length=150;
      comment = 'For this Row: Sales.Sum'||put(Sales.sum,comma14.)||
                ' ** divided by ** grptot ' ||put(grptot,comma14.);
    endcomp;
  run;

ods html(id=ex4d) close;
ods listing;


  
