** Beginning Examples: default behavior;
ods html close;
proc sort data=sashelp.shoes out=shoes;
  by region product;
  where region in ('Asia', 'Canada', 'Pacific');
run;

ods html(id=d2a) file="&outpath\demo2_default.html";
proc report data=shoes;
  title 'A1) Default Report Only Numeric Variables';
  column sales returns inventory ;
run;

proc report data=shoes;
  title 'A2) Default Report Only Numeric Variables';
  title2 'With COMPUTE block for new report items';
  column sales returns Profit inventory PctInv;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  compute profit;
    profit = sum(sales.sum,-1*returns.sum);
  endcomp;
  compute pctinv;
    pctinv = sales.sum / inventory.sum;
  endcomp;
run;

proc report data=shoes;
  title 'A3) Default Report Only Numeric Variables';
  title2 'With 1 COMPUTE block for both new report items';
  column sales returns Profit inventory PctInv;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
run;

proc report data=shoes;
  title 'A4) Missing Values generated with wrong COMPUTE block';
  title2 'With 1 COMPUTE block for both new report items';
  column sales returns Profit inventory PctInv;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  compute profit;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
run;

proc report data=shoes spanrows;
  title 'B) Using GROUP items with ANALYSIS and COMPUTED columns';
  title2 'All calculations done in COMPUTE block for last variable on report row';
  column region product sales returns Profit inventory PctInv ;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
run;

proc report data=shoes spanrows out=work.repout;
  title 'C) Adding Subtotals and Grand Totals';
  column region product sales returns Profit inventory PctInv ;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  break after region/summarize;
  rbreak after / summarize;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
run;

proc print data=work.repout;
  title 'See _BREAK_ variable created by PROC REPORT';
run;
ods html(id=d2a) close;

ods html(id=d2b) file="&outpath\demo2_use_all_COMPUTE.html";
proc report data=shoes spanrows out=work.compout;
  where region in ('Asia' 'Canada') and
        product in ('Boot' 'Sandal' 'Slipper');
  title 'D) Many of the Other Forms of COMPUTE';
  column region product sales returns Profit inventory PctInv ;
  define region / group;
  define product / group;
  define profit / computed f=dollar14.;
  define pctinv / computed f=percent9.2;
  break after region/summarize;
  rbreak after / summarize;
  compute pctinv;
    profit = sum(sales.sum,-1*returns.sum);
    pctinv = sales.sum / inventory.sum;
  endcomp;
  compute before _page_;
    line '1) COMPUTE BEFORE _PAGE_';
  endcomp;
  compute before;
    line '2) COMPUTE BEFORE';
  endcomp; 
  compute before region;
    line '3) COMPUTE BEFORE region';
  endcomp;
  compute after region;
    line '4) COMPUTE AFTER region';
  endcomp;
  compute after;
    line '5) COMPUTE AFTER';
  endcomp;
  compute after _page_;
    line '6) COMPUTE AFTER _PAGE_';
  endcomp;
run;

ods html(id=d2b) close;
title;
ods html;

